================
Upcoming Updates
================

These are the planned updates either being seriously 
researched or actively developed upon.

This is also a great place for contributors to get 
ideas on how to help with mudicom.

* Detect multiple images within a DICOM file
* Ability to extract multiple images from a DICOM file
* Exception handling for unsupported DICOM files

